==> ezpublish-4.0.0.tgz: ezpublish/extension/ezodf/translations/por-BR/translation.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>extension/ezodf</name>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Substituir</translation>
    </message>
    <message>
        <source>Choose document placement</source>
        <translation>Escolher colocação do documento</translation>
    </message>
    <message>
        <source>Upload file</source>
        <translation>Carregar arquivo</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Export Object</source>
        <translation>Exportar objeto</translation>
    </message>
    <message>
        <source>OpenOffice.org import</source>
        <translation>Importar OpenOffice.org</translation>
    </message>
    <message>
        <source>OpenOffice.org export</source>
        <translation>Exportar OpenOffice.org</translation>
    </message>
    <message>
        <source>Export eZ publish content to OpenOffice.org</source>
        <translation>Exportar conteúdo do eZ Publish para OpenOffice.org</translation>
    </message>
    <message>
        <source>Here you can export any eZ publish content object to an OpenOffice.org Writer document format.</source>
        <translation>Aqui você pode exportar qualquer objeto de conteúdo do eZ Publish para um documento OpenOffice.org Writer.</translation>
    </message>
    <message>
        <source>Document is now imported</source>
        <translation>O documento foi agora importado</translation>
    </message>
    <message>
        <source>The object was imported as: %class_name</source>
        <translation>O objeto foi importado como: %class_name</translation>
    </message>
    <message>
        <source>Document imported as</source>
        <translation>Documento importado como</translation>
    </message>
    <message>
        <source>The images are placed in the media and can be re-used.</source>
        <translation>As imagens foram colocadas na pasta mídia e podem ser reutilizadas.</translation>
    </message>
    <message>
        <source>Import another document</source>
        <translation>Importar outro documento</translation>
    </message>
    <message>
        <source>Import OpenOffice.org document</source>
        <translation>Importar documento OpenOffice.org</translation>
    </message>
    <message>
        <source>Replace document</source>
        <translation>Substituir documento</translation>
    </message>
    <message>
        <source>Import to</source>
        <translation>Importar para</translation>
    </message>
    <message>
        <source>You can import OpenOffice.org Writer documents directly into eZ publish from this page. You are
asked where to place the document and eZ publish does the rest. The document is converted into
the appropriate class during the import, you get a notice about this after the import is done.
Images are placed in the media library so you can re-use them in other articles.</source>
        <translation>Você pode importar documentos OpenOffice.org Writer diretamente para o eZ Publish a partir desta página.(new line)
Você escolherá onde colocar o documento e o eZ Publish fará o resto. O documento é convertido para(new line)
a classe apropriada durante a importação, você receberá um aviso sobre isto após concluída a importação(new line)
As imagens são colocadas na biblioteca de mídia e você poderá reutilizá-las em outros artigos.</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/browse</name>
    <message>
        <source>Choose document placement</source>
        <translation>Escolher colocação do documento</translation>
    </message>
    <message>
        <source>Please choose the placement for the OpenOffice.org object.

    Select the placements and click the %buttonname button.
    Using the recent and bookmark items for quick placement is also possible.
    Click on placement names to change the browse listing.</source>
        <translation>Favor escolher a colocação do objeto OpenOffice.org.(new line)
(new line)
(sp)(sp)(sp)(sp)Selecione as colocações e clique no botão %buttonname.(new line)
sp)(sp)(sp)(sp)Também é possível usar os recentes itens do bookmark para rápida colocação.(new line)
(sp)(sp)(sp)(sp)Clique nos nomes das colocações para modificar a lista de procura.</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selecionar</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/export/error</name>
    <message>
        <source>Destination file format not supported</source>
        <translation>Formato de documento de destino não é suportado</translation>
    </message>
    <message>
        <source>PDF conversion failed</source>
        <translation>Conversão de PDF falhou</translation>
    </message>
    <message>
        <source>Word conversion failed</source>
        <translation>Conversão de Word falhou</translation>
    </message>
    <message>
        <source>Unable to fetch node, or no read access</source>
        <translation>Incapaz de alcançar nó, ou nenhum acesso lido</translation>
    </message>
    <message>
        <source>Unable to open file %1 on server side</source>
        <translation>Incapaz de abrir o documento %1 no lado do servidor</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/import/error</name>
    <message>
        <source>File extension or type is not allowed.</source>
        <translation>Extensão ou tipo de documento não é permitido.</translation>
    </message>
    <message>
        <source>Could not parse XML.</source>
        <translation>Não foi possível processar XML.</translation>
    </message>
    <message>
        <source>Can not open socket. Please check if extension/ezodf/daemon.php is running.</source>
        <translation>Não foi possível abrir o socket. Favor checar se a extensão extension/ezodf/daemon.php está rodando.</translation>
    </message>
    <message>
        <source>Can not convert the given document.</source>
        <translation>Não é possível converter o documento dado.</translation>
    </message>
    <message>
        <source>Unable to call daemon. Fork can not create child process.</source>
        <translation>Não foi possível comunicar-se com daemon, então nenhum processo de conversão pôde ser iniciado.</translation>
    </message>
    <message>
        <source>Daemon reported error.</source>
        <translation>Daemon reportou erro.</translation>
    </message>
    <message>
        <source>Unknown node.</source>
        <translation>Nó desconhecido.</translation>
    </message>
    <message>
        <source>Access denied.</source>
        <translation>Acesso negado.</translation>
    </message>
    <message>
        <source>Error during import.</source>
        <translation>Erro durante a importação.</translation>
    </message>
    <message>
        <source>Unknown content class specified in odf.ini:</source>
        <translation>Classe de conteúdo especificada em odf.ini é desconhecida:</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Erro desconhecido.</translation>
    </message>
    <message>
        <source>Filetype: </source>
        <translation>Tipo de documento:</translation>
    </message>
    <message>
        <source>Unable to fetch node with id  </source>
        <translation>Incapaz de alcançar o nó com o id(sp)(sp)</translation>
    </message>
    <message>
        <source>Folder for images could not be created, access denied.</source>
        <translation>Pasta para imagens não pôde ser criada, acesso negado.</translation>
    </message>
    <message>
        <source>Document is not suported.</source>
        <translation>Documento não é suportado.</translation>
    </message>
    <message>
        <source>Cannot import. File not found. Already imported?</source>
        <translation>Não é possível importar. Arquivo não encontrado. Este já foi importado?</translation>
    </message>
    <message>
        <source>Cannot import document, supplied placement nodeID is not valid.</source>
        <translation>Não é possível importar documento, colocação de nodeID fornecido é inválido.</translation>
    </message>
    <message>
        <source>Cannot store uploaded file, cannot import.</source>
        <translation>Não é possível armazenar documento carregado, não é possível importar.</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/popupmenu</name>
    <message>
        <source>Export OpenOffice.org</source>
        <translation>Exportar OpenOffice.org</translation>
    </message>
    <message>
        <source>Export PDF</source>
        <translation>Exportar PDF</translation>
    </message>
    <message>
        <source>Export Word</source>
        <translation>Exportar Word</translation>
    </message>
    <message>
        <source>Import OpenOffice.org</source>
        <translation>Importar OpenOffice.org</translation>
    </message>
    <message>
        <source>Replace OpenOffice.org</source>
        <translation>Substituir OpenOffice.org</translation>
    </message>
</context>
</TS>

==> ezpublish-4.1.3.tgz: ezpublish/extension/ezodf/translations/por-BR/translation.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>extension/ezodf</name>
    <message>
        <source>Upload file</source>
        <translation>Carregar arquivo</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Export Object</source>
        <translation>Exportar objeto</translation>
    </message>
    <message>
        <source>OpenOffice.org import</source>
        <translation>Importar OpenOffice.org</translation>
    </message>
    <message>
        <source>OpenOffice.org export</source>
        <translation>Exportar OpenOffice.org</translation>
    </message>
    <message>
        <source>Document is now imported</source>
        <translation>O documento foi agora importado</translation>
    </message>
    <message>
        <source>The object was imported as: %class_name</source>
        <translation>O objeto foi importado como: %class_name</translation>
    </message>
    <message>
        <source>Document imported as</source>
        <translation>Documento importado como</translation>
    </message>
    <message>
        <source>Import another document</source>
        <translation>Importar outro documento</translation>
    </message>
    <message>
        <source>Import OpenOffice.org document</source>
        <translation>Importar documento OpenOffice.org</translation>
    </message>
    <message>
        <source>Replace document</source>
        <translation>Substituir documento</translation>
    </message>
    <message>
        <source>Import to</source>
        <translation>Importar para</translation>
    </message>
    <message>
        <source>Export eZ Publish content to OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Here you can export any eZ Publish content object to an OpenOffice.org Writer document format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The images are placed in the media library and can be re-used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can import OpenOffice.org Writer documents directly into eZ Publish from this page. You are
asked where to place the document and eZ Publish does the rest. The document is converted into
the appropriate class during the import, you get a notice about this after the import is done.
Images are placed in the media library so you can re-use them in other articles.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/browse</name>
    <message>
        <source>Choose document placement</source>
        <translation>Escolher colocação do documento</translation>
    </message>
    <message>
        <source>Please choose the placement for the OpenOffice.org object.

    Select the placements and click the %buttonname button.
    Using the recent and bookmark items for quick placement is also possible.
    Click on placement names to change the browse listing.</source>
        <translation>Favor escolher a colocação do objeto OpenOffice.org.(new line)
(new line)
(sp)(sp)(sp)(sp)Selecione as colocações e clique no botão %buttonname.(new line)
sp)(sp)(sp)(sp)Também é possível usar os recentes itens do bookmark para rápida colocação.(new line)
(sp)(sp)(sp)(sp)Clique nos nomes das colocações para modificar a lista de procura.</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selecionar</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/export/error</name>
    <message>
        <source>Destination file format not supported</source>
        <translation>Formato de documento de destino não é suportado</translation>
    </message>
    <message>
        <source>PDF conversion failed</source>
        <translation>Conversão de PDF falhou</translation>
    </message>
    <message>
        <source>Word conversion failed</source>
        <translation>Conversão de Word falhou</translation>
    </message>
    <message>
        <source>Unable to fetch node, or no read access</source>
        <translation>Incapaz de alcançar nó, ou nenhum acesso lido</translation>
    </message>
    <message>
        <source>Unable to open file %1 on server side</source>
        <translation>Incapaz de abrir o documento %1 no lado do servidor</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/import/error</name>
    <message>
        <source>File extension or type is not allowed.</source>
        <translation>Extensão ou tipo de documento não é permitido.</translation>
    </message>
    <message>
        <source>Could not parse XML.</source>
        <translation>Não foi possível processar XML.</translation>
    </message>
    <message>
        <source>Can not open socket. Please check if extension/ezodf/daemon.php is running.</source>
        <translation>Não foi possível abrir o socket. Favor checar se a extensão extension/ezodf/daemon.php está rodando.</translation>
    </message>
    <message>
        <source>Can not convert the given document.</source>
        <translation>Não é possível converter o documento dado.</translation>
    </message>
    <message>
        <source>Unable to call daemon. Fork can not create child process.</source>
        <translation>Não foi possível comunicar-se com daemon, então nenhum processo de conversão pôde ser iniciado.</translation>
    </message>
    <message>
        <source>Daemon reported error.</source>
        <translation>Daemon reportou erro.</translation>
    </message>
    <message>
        <source>Unknown node.</source>
        <translation>Nó desconhecido.</translation>
    </message>
    <message>
        <source>Access denied.</source>
        <translation>Acesso negado.</translation>
    </message>
    <message>
        <source>Error during import.</source>
        <translation>Erro durante a importação.</translation>
    </message>
    <message>
        <source>Unknown content class specified in odf.ini:</source>
        <translation>Classe de conteúdo especificada em odf.ini é desconhecida:</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Erro desconhecido.</translation>
    </message>
    <message>
        <source>Filetype: </source>
        <translation>Tipo de documento:</translation>
    </message>
    <message>
        <source>Folder for images could not be created, access denied.</source>
        <translation>Pasta para imagens não pôde ser criada, acesso negado.</translation>
    </message>
    <message>
        <source>Cannot import. File not found. Already imported?</source>
        <translation>Não é possível importar. Arquivo não encontrado. Este já foi importado?</translation>
    </message>
    <message>
        <source>Cannot import document, supplied placement nodeID is not valid.</source>
        <translation>Não é possível importar documento, colocação de nodeID fornecido é inválido.</translation>
    </message>
    <message>
        <source>Cannot store uploaded file, cannot import.</source>
        <translation>Não é possível armazenar documento carregado, não é possível importar.</translation>
    </message>
    <message>
        <source>Unable to fetch node with id </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/popupmenu</name>
    <message>
        <source>Export PDF</source>
        <translation>Exportar PDF</translation>
    </message>
    <message>
        <source>Export Word</source>
        <translation>Exportar Word</translation>
    </message>
    <message>
        <source>OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
